package de.intevation.flys.artifacts.states;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.MINFOArtifact;
import de.intevation.flys.artifacts.model.CalculationResult;
import de.intevation.flys.artifacts.model.DataFacet;
import de.intevation.flys.artifacts.model.FacetTypes;
import de.intevation.flys.artifacts.model.MiddleBedHeightData;
import de.intevation.flys.artifacts.model.MiddleBedHeightFacet;
import de.intevation.flys.artifacts.model.MiddleBedHeightCalculation;


public class MiddleBedHeight extends DefaultState implements FacetTypes {

    private static final Logger logger = Logger.getLogger(MiddleBedHeight.class);


    @Override
    public Object computeAdvance(
        FLYSArtifact artifact,
        String       hash,
        CallContext  context,
        List<Facet>  facets,
        Object       old
    ) {
        logger.debug("MiddleBedHeight.computeAdvance");

        List<Facet> newFacets = new ArrayList<Facet>();

        CalculationResult res = old instanceof CalculationResult
            ? (CalculationResult) old
            : new MiddleBedHeightCalculation().calculate((MINFOArtifact) artifact);

        if (facets == null || res == null) {
            return res;
        }

        MiddleBedHeightData[] data = (MiddleBedHeightData[]) res.getData();

        logger.debug("Calculated " + data.length + " MiddleBedHeightData objects");

        String id  = getID();
        int    idx = 0;

        for (MiddleBedHeightData d: data) {
            newFacets.add(new MiddleBedHeightFacet(
                idx,
                MIDDLE_BED_HEIGHT,
                buildMiddleBedHeightName(artifact, context, d),
                ComputeType.ADVANCE,
                id,
                hash
            ));

            idx++;
        }

        Facet csv = new DataFacet(
            CSV, "CSV data", ComputeType.ADVANCE, hash, id);

        // TODO ADD PDF FACET

        newFacets.add(csv);

        logger.debug("Created " + newFacets.size() + " new Facets.");

        facets.addAll(newFacets);

        return res;
    }


    protected String buildMiddleBedHeightName(
        FLYSArtifact        artifact,
        CallContext         cc,
        MiddleBedHeightData data
    ) {
        logger.error("TODO: Implement buildMiddleBedHeightName");
        return "TODO: Implement buildMiddleBedHeightName";
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
